{ config, pkgs, lib, mail, ... }:
{
  # TODO
  # Linter (ale)
  # Markdown spellcheck
  # Autocomplete
  # Missing plugins
  # Telescope and fuzzy finder
  # Ruff linter for python and black formatting on save
  # Language support for python, go, tofu, terraform, yaml
  # Format on exit
  # Trailing spaces in statusline
  # Good example: https://github.com/fred-drake/neovim/blob/master/config/python/language.nix

  imports = [
    ./telescope.nix
  ];

  programs.nixvim = {
    colorscheme = "sonokai";
    enable = true;
    extraPlugins = [
      pkgs.vimPlugins.indentLine
      pkgs.vimPlugins.polyglot
      pkgs.vimPlugins.sonokai
    ];
    globals = {
      mapleader = ",";
      sonokai_style = "atlantis";
      sonokai_disable_italic_comment = 1;
    };
    keymaps = [];
    opts = {
      colorcolumn = "88";
      cursorline = true;
      number = true;
      termguicolors = true;
    };
    plugins = {
      cmp = {
        enable = true;  # Completion
        autoEnableSources = true;
        settings.sources = [
          { name = "nvim_lsp"; }
          { name = "path"; }
          { name = "buffer"; }
        ];
        settings.mapping = {
          "<C-d>" = "cmp.mapping.scroll_docs(-4)";
          "<C-f>" = "cmp.mapping.scroll_docs(4)";
          "<C-Space>" = "cmp.mapping.complete()";
          "<C-e>" = "cmp.mapping.close()";
          "<Tab>" = "cmp.mapping(cmp.mapping.select_next_item({behavior = cmp.SelectBehavior.Select}), {'i', 's'})";
          "<S-Tab>" = "cmp.mapping(cmp.mapping.select_prev_item({behavior = cmp.SelectBehavior.Select}), {'i', 's'})";
          "<CR>" = "cmp.mapping.confirm({ select = false, behavior = cmp.ConfirmBehavior.Replace })";
        };
      };
      committia.enable = true;  # Enhanced git commits
      gitgutter.enable = true;  # Show git change in first line
      guess-indent.enable = true;  # Guess indent of the file
      lsp.enable = true;
      lsp.servers.pylsp = {
        enable = true;
        settings.plugins = {
          black.enabled = true;
          isort.enabled = true;
          ruff.enabled = true;
          ruff.formatEnabled = false;
        };
      };
      lsp-format.enable = true;  # Automatically format on save
      lsp-lines.enable = true;  # Display lsp hints in lines
      lsp-signature.enable = true;  # Show function signature when typing
      lualine.enable = true;  # Statusline
      treesitter.enable = true;
      web-devicons.enable = true;
    };
  };
}
